%global _use_internal_dependency_generator 0
%global contentdir %{_localstatedir}/www/%{name}

%bcond_without selinux
%if %{with selinux}
%global selinuxtype targeted
%endif

Summary:   Multi Router Traffic Grapher
Name:      mrtg
Version:   2.17.10
Release:   5%{?dist}
License:   GPLv2+
URL:       http://oss.oetiker.ch/mrtg/
Source0:   http://oss.oetiker.ch/mrtg/pub/mrtg-%{version}.tar.gz
Source1:   filter-requires-mrtg.sh
Source2:   filter-provides-mrtg.sh
Source3:   mrtg.cfg
Source4:   mrtg-httpd.conf
Source5:   mrtg.tmpfiles
Source6:   mrtg.service
Source7:   mrtg.timer
%if %{with selinux}
Source100: %{name}.te
Source101: %{name}.if
Source102: %{name}.fc
%endif

Patch3000: mrtg-2.15.0-lib64.patch
Patch3001: mrtg-2.17.2-socket6-fix.patch
Patch3002: mrtg-2.17.4-cfgmaker-ifhighspeed.patch

BuildRequires: make gcc
BuildRequires: gd-devel libpng-devel perl-generators systemd-units
Requires:      gd perl-Socket6 perl-IO-Socket-IP perl-locale
%if %{with selinux}
Requires:      (%{name}-selinux if selinux-policy-%{selinuxtype})
%endif
Requires(post):   systemd-units
Requires(preun):  systemd-units
Requires(postun): systemd-units

%global __find_requires %{SOURCE1}
%global __find_provides %{SOURCE2}


%description
The Multi Router Traffic Grapher (MRTG) is a tool to monitor
the traffic load on network links. MRTG generates HTML pages
containing PNG images which provide a LIVE visual representation
of this traffic.

%if %{with selinux}
%package selinux
Summary:        mrtg SELinux policy
BuildRequires:  selinux-policy-devel
Requires:       selinux-policy-%{selinuxtype}
Requires(post): selinux-policy-%{selinuxtype}
%{?selinux_requires}
BuildArch:      noarch

%description selinux
Custom SELinux policy module
%endif


%prep
%autosetup -p1
for i in doc/mrtg-forum.1 doc/mrtg-squid.1 CHANGES; do
    iconv -f iso-8859-1 -t utf-8 < "$i" > "${i}_"
    mv "${i}_" "$i"
done
rm -rf contrib/nt-services


%build
%configure
make LIBS='-lgd -lm'
find contrib -type f -exec \
    %{__perl} -e 's,^#!/\s*\S*perl\S*,#!%{__perl},gi' -p -i \{\} \;
find contrib -name "*.pl" -exec %{__perl} -e 's;\015;;gi' -p -i \{\} \;
find contrib -type f | xargs chmod a-x

%if %{with selinux}
mkdir selinux
cp -p %{SOURCE100} %{SOURCE101} %{SOURCE102} selinux/
make -f %{_datadir}/selinux/devel/Makefile %{name}.pp
bzip2 -9 %{name}.pp
%endif


%install
rm -rf   %{buildroot}
%make_install

mkdir -p %{buildroot}%{_sysconfdir}/mrtg
mkdir -p %{buildroot}%{_localstatedir}/lib/mrtg
mkdir -p %{buildroot}%{_localstatedir}/lock/mrtg
mkdir -p %{buildroot}%{contentdir}
mkdir -p %{buildroot}%{_sysconfdir}/httpd/conf.d

install -m 644 images/*   %{buildroot}%{contentdir}/
sed 's,@CONTENTDIR@,%{contentdir},g; s,@LIBDIR@,%{_localstatedir}/lib/mrtg,g' \
    %{SOURCE3} > %{buildroot}%{_sysconfdir}/mrtg/mrtg.cfg
chmod 644 %{buildroot}%{_sysconfdir}/mrtg/mrtg.cfg

install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/httpd/conf.d/mrtg.conf

mkdir -p %{buildroot}/%{_tmpfilesdir}
install -p -D -m 644 %{SOURCE5} %{buildroot}/%{_tmpfilesdir}/mrtg.conf

mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/mrtg.service
install -p -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/mrtg.timer

for i in mrtg cfgmaker indexmaker mrtg-traffic-sum; do
    sed -i 's;@@lib@@;%{_lib};g' "%{buildroot}"%{_bindir}/"$i"
done

sed -i 's;@@lib@@;%{_lib};g' "%{buildroot}"%{_mandir}/man1/*.1

%if %{with selinux}
install -D -m 0644 %{name}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
install -D -p -m 0644 selinux/%{name}.if %{buildroot}%{_datadir}/selinux/devel/include/distributed/%{name}.if
%endif

%post
install -d -m 0755 -o root -g root /var/lock/mrtg
restorecon /var/lock/mrtg
%systemd_post mrtg.service

%preun
if [ $1 -eq 0 ]; then
  rm -rf /var/lock/mrtg
fi
%systemd_preun mrtg.service

%postun
%systemd_postun_with_restart mrtg.service 

%if %{with selinux}
%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
%selinux_relabel_post -s %{selinuxtype}

if [ "$1" -le "1" ]; then
   %systemd_postun_with_restart mrtg.service
fi

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} %{name}
    %selinux_relabel_post -s %{selinuxtype}
fi
%endif

%files
%license COPYING COPYRIGHT
%doc contrib CHANGES README THANKS
%dir %{_sysconfdir}/mrtg
%config(noreplace) %{_sysconfdir}/mrtg/mrtg.cfg
%config(noreplace) %{_sysconfdir}/httpd/conf.d/mrtg.conf
%{contentdir}
%{_bindir}/*
%{_libdir}/mrtg2
%exclude %{_libdir}/mrtg2/Pod
%{_mandir}/*/*
%exclude %{_datadir}/mrtg2/icons
%exclude %{_datadir}/doc/mrtg2
%dir %{_localstatedir}/lib/mrtg
%{_tmpfilesdir}/mrtg.conf
%ghost /var/lock/mrtg
%{_unitdir}/mrtg.service
%{_unitdir}/mrtg.timer

%if %{with selinux}
%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.*
%{_datadir}/selinux/devel/include/distributed/%{name}.if
%ghost %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{name}
%endif

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.17.10-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.17.10-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.17.10-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.17.10-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 15 2023 Miaojun Dong <zoedong@tencent.com> - 2.17.10-1
- initial build
